# Econometric Modeling

Globally consistent trends in clustering are far from clear in the plots above, but it is clear that there exists variation in the intensity of clustering as time passes.  Extracting the marginal effect of COTEL intensity requires econometric exploration.  In this analysis we employ three approaches to explore this impact on measures of both revenue yield (per capita revenue, `pcrev`) and fiscal capacity (per capita annual payroll, `pcap`).

**Pooled [OLS](http://en.wikipedia.org/wiki/Ordinary_least_squares)** serves as the baseline specification.  It is an exploratory modeling exercise to place the integration of spatial and temporal dependency in context.  Furthermore, given the absence of an explicitly modeled spatial dependency structure, the pooled OLS approach allows us to explore the impact of COTEL intensity on the LISAs defined above.  This subset of models sets as a dependent each LISA/fiscal indicator/weight matrix combination.  For example, `w_db_b_i` corresponds to the Local Moran's I values for each county generated with the Binary Distance Band weight matrix for clustering of per capita revenue.

**Repeated Cross-Sectional [Spatial Lag Models](https://geodacenter.asu.edu/spatial-lag-and)** provide year-specific assessments of COTEL intensity impact while incorporating the fiscal behavior of the local neighborhood.  All of these models were evaluated with the Rook Contiguity weight matrix (`w_rook`).  This series of models (one model per 15 years for both per capita revenue and per capita annual payroll) provide some sense of temporal variation in impact over time. 

**[Fixed Effects Panel Analysis](http://en.wikipedia.org/wiki/Fixed_effects_model)** does not contain a spatial component, but it does enable us to incorporate county-specific unobservables.  In so doing, we are afforded a clearer signal of the impact of COTEL intensity on changes in the fiscal indicators.

The goal in utilizing this model ensemble is to seek common patterns from a variety of data views.  That being said, in each of these models, the specification is consistent within either of the fiscal yield (`pcrev`) and fiscal capacity (`pcap`) model sets.  The independent variables for the fiscal yield models are as follows:

+ Gross State Product (`gsp`) provides a measure of statewide economic activity.  It is meant to capture some notion of the available resources in the state.  It is omitted in the repeated annual cross-sections because it adds no variation.
+ Lagged Population Growth (`lpop_growth`) provides a measure of demand for public services and housing.  In the case of the former, public service demand is a determinant of the revenues desired by a county.  The latter demand drives up the price of housing.
+ State Level Unemployment Rate (`st_unempr`) captures the business cycle.
+ Housing Permits per Unit Housing (`permit_rate`) is related to population growth, but it provides a more direct, concurrent measure for housing market pressures.  More importantly, it captures the TABOR growth measure (new construction) in a clear way.
+ Vacancy Rate (`vac_rate`) is the most direct measure of housing demand.  There are reasons for both the population growth and permit rate indicators to separate from stock utilization.  For example, population growth may be accompanied by increases in household size and permit rates may increase due to developer forecasting assumptions.  Neither is possible with the vacancy rate.
+ Residential/Non-Residential Assessment Base Ratio (`prop_ratio`) captures the county-specific value of the measurement used to set statewide assessment rates due to the Gallagher Amendment.
+ Cumulative Impact of TABOR & SLPTR (`intensity_stock`) is our primary variable of interest.  

The fiscal yield models include all of the above covariates and fiscal capacity (`pcap`), while the fiscal capacity models use `pcap` as the dependent variable.  Dollar related values have been inflation adjusted (base year = 2009).